Hieronder zie je een visuele voorstelling van twee tabellen:

![](file:///home/vincent/Documents/DatabankenIntro/2023/labo1/eerste-erd.png)

Schrijf zelf de `CREATE`-instructie om de tabel `Boeken` aan te maken.
Voer je code uit wanneer je klaar bent om ze te testen.
Controleer de output van je script.
Indien de instructie mis loopt, lees dan de foutmelding en probeer het probleem op te lossen.

Sla je uiteindelijke script op onder MySQL/Essentieel/CreateBoeken.sql.
